==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ImageBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageBuilder>{
  public ImageBuilder() {
    this(false);
  }
  public ImageBuilder(java.lang.Boolean validationEnabled) {
    this(new Image(), validationEnabled);
  }
  public ImageBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Image(), validationEnabled);
  }
  public ImageBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image instance) {
    this(fluent, instance, false);
  }
  public ImageBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withChecksum(instance.getChecksum()); 
    fluent.withChecksumType(instance.getChecksumType()); 
    fluent.withFormat(instance.getFormat()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image instance) {
    this(instance,false);
  }
  public ImageBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withChecksum(instance.getChecksum()); 
    this.withChecksumType(instance.getChecksumType()); 
    this.withFormat(instance.getFormat()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image build() {
    Image buildable = new Image(fluent.getChecksum(),fluent.getChecksumType(),fluent.getFormat(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageBuilder that = (ImageBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ImageBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageBuilder extends ImageFluentImpl<ImageBuilder> implements VisitableBuilder<Image,ImageBuilder>{
  public ImageBuilder() {
    this(false);
  }
  public ImageBuilder(Boolean validationEnabled) {
    this(new Image(), validationEnabled);
  }
  public ImageBuilder(ImageFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageBuilder(ImageFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Image(), validationEnabled);
  }
  public ImageBuilder(ImageFluent<?> fluent,Image instance) {
    this(fluent, instance, false);
  }
  public ImageBuilder(ImageFluent<?> fluent,Image instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withChecksum(instance.getChecksum()); 
    fluent.withChecksumType(instance.getChecksumType()); 
    fluent.withFormat(instance.getFormat()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageBuilder(Image instance) {
    this(instance,false);
  }
  public ImageBuilder(Image instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withChecksum(instance.getChecksum()); 
    this.withChecksumType(instance.getChecksumType()); 
    this.withFormat(instance.getFormat()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ImageFluent<?> fluent;
  Boolean validationEnabled;
  public Image build() {
    Image buildable = new Image(fluent.getChecksum(),fluent.getChecksumType(),fluent.getFormat(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
